<!-- $Revision: 6375 $ -->
<HTML>
  <HEAD>
    <TITLE>Subskrybenci listy <MM-List-Name></TITLE>
    <meta http-equiv="Content-Type" content="text/html; charset=iso-8859-2">  
  </HEAD>
  <BODY BGCOLOR="#ffffff">

    <P>
    <TABLE WIDTH="100%" COLS="1" BORDER="0" CELLSPACING="4" CELLPADDING="5">
      <TR>
	<TD COLSPAN="2" WIDTH="100%" BGCOLOR="#99CCFF" ALIGN="CENTER">
	  <B><FONT COLOR="#000000" SIZE="+1">
		Subskrybenci listy <MM-List-Name></FONT></B>
	</TD>
      </TR>
      <TR>
	<TD COLSPAN="2" WIDTH="100%" ALIGN="CENTER">
	    
          <P align = "right"> <MM-lang-form-start><MM-displang-box>
                       <MM-list-langs><MM-form-end></p>        

	  <P>Kliknij na sw&oacute;j adres, &#380;eby wej&#347;&#263; na stron&#281; z opcjami
             subskrypcji.
            <br><I>(Na adresy pisane kursyw&#261; nie s&#261; wysy&#322;ane listy)</I></P>
	</TD>
      </TR>
      <TR WIDTH="100%" VALIGN="top">
	<TD BGCOLOR="#FFF0D0" WIDTH="50%">
	  <center>
	    <B><FONT COLOR="#000000"><MM-Num-Reg-Users>
		  Zwykli prenumeratorzy listy <MM-List-Name>:</FONT></B>
	  </center>
	</TD>
	<TD BGCOLOR="#FFF0D0" WIDTH="50%">
	  <center>
	    <B><FONT COLOR="#000000"><MM-Num-Digesters> 
		  Prenumeratorzy otrzymuj&#261;cy wiadomo&#347;&#263; w paczkach <MM-List-Name>:</FONT></B> 
	  </center>
	</TD>
      </TR>
      <TR VALIGN="top">
	<td>
	  <P><MM-Regular-Users>
	</td>
	<td>
	  <P><MM-Digest-Users>
	</td>
      </tr>
    </table>
<MM-Mailman-Footer>
</BODY>
</HTML>
